module.exports = function(grunt) {
	require('load-grunt-tasks')(grunt);
	require('time-grunt')(grunt);

	// ARRAY FOR ALL YOUR JS FILES IN PAGE HEADER
	var jsHeader = ['js/header.js'];

	// ARRAY FOR ALL YOUR JS FILES JUST BEFORE CLOSING </BODY>-TAG
	var jsFoundation = ['bower_components/jquery/dist/jquery.js',
		'bower_components/foundation-sites/dist/foundation.js',
		'bower_components/what-input/what-input.js'
		];
		
	// ARRAY FOR ALL YOUR CUSTOM JS FILES
	var jsApp = ['js/app.js', 'js/_*.js'];
	var jsAll = jsFoundation.concat(jsApp);
	
	// BASIC FILE TEMPLATES
	var headerJs = '// WRITE JAVASCRIPT FOR >> HEADER << HERE ...';
	var appJs = '// WRITE JAVASCRIPT FOR >> FOOTER << HERE ...';
	var settingsScss = '// GET SETTINGS FILE FROM HERE:\n// https://github.com/zurb/foundation-sites/blob/develop/scss/settings/_settings.scss';
	var styleScss = '';
	var varsScss = '';
	var appScss = '@import "vars";\n@import "settings";\n@import "foundation";\n@include foundation-everything;\n@import "style";';
	
	// CONFIGURE YOUR TASKS HERE
	grunt.initConfig({
		pkg: grunt.file.readJSON('package.json'),
		connect: {
			all: {
				options: {
					port: 35729,
					hostname: "dev2.t1.local",
					keepalive: true
				}
			}
		},
		clean: {
			options: {
				force: true
			},
			plugins: ['../../../../../../typo3temp/Cache/*'],
		},
		webfont: {
			icons: {
				src: ['bower_components/foundation-icon-fonts/svgs/*.svg', 'svg/*.svg'],
				dest: '../../Public/Fonts/',
				destCss: '../../Public/Styles',
				options: {
					templateOptions: {
						baseClass: 'icon',
						classPrefix: ''
					}
				}
			}
		},
		
		// SASS COMPILER
		sass: {
			options: {
				includePaths: ['bower_components/foundation-sites/scss', 'bower_components/motion-ui']
			},
			dist: {
				options: {
					// CAN BE: nested, expanded, compact, compressed.
					outputStyle: 'expanded',
					sourceMap: false,
				},
				files: {
					'../../Public/Styles/foundation.css': 'scss/app.scss'
				}
			}
		},
		// AUTOMATICALLY ADD VENDOR PREFIXES
		autoprefixer: {
			dist: {
				files: {
					'../../Public/Styles/foundation.css': '../../Public/Styles/foundation.css'
				}
			}
		},
		// JAVASCRIPT VALIDATION
		jshint: {
			options: {
				//  CHANGE JSHINT SETTINGS IN FILE
				jshintrc: '_.jshintrc'
			},
			all: ['Gruntfile.js', jsApp.concat(jsHeader), 'js/header.js']
		},
		uglify: {
			options: {
				sourceMap: true,
				beautify: {
					width: 80,
					// MAKE JS FILES READABLE true/false
					beautify: true
				},
			},
			dist: {
				files: {
					// THE NAME AND LOCATION OF JS FILES TO BE WRITTEN to : from Array
					'../../Public/JavaScript/header.js': jsHeader,
					'../../Public/JavaScript/foundation.js': jsAll
				}
			}
		},
		// TRIGGER TASK TO RUN ON "grunt watch"
		watch: {
			grunt: {
				options: {
					reload: true
				},
				files: ['Gruntfile.js']
			},
			sass: {
				files: 'scss/*.scss',
				tasks: ['sass', 'autoprefixer']
			},
			js: {
				files: [
				jsAll, '<%= jshint.all %>'],
				tasks: ['jshint']
			},
			livereload: {
				options: {
					livereload: true
				},
				// CHOOSE WHICH FILES YOU WANT TO USE IN livereload
				files: ['../../Public/JavaScript/**/*',
					'../../Styles/**/*',
					'../Templates/**/*',
					'../Templates/Extensions/**/*',
					'../../../Configuration/TypoScript/**/*'],
			}
		}
	});
	// SETUP TASK - CUSTOM TASK TO CREATE STRUCTURE
	grunt.registerTask('setup', 'Create files and folders.', function() {
		var createFiles = [
			['js/header.js', headerJs],
			['js/app.js', appJs],
			['scss/_settings.scss', settingsScss],
			['scss/_style.scss', styleScss],
			['scss/_vars.scss', varsScss],
			['scss/app.scss', appScss],
			['svg/svg.txt', '// Placeholder']
		];
		var files = '';
		for (var key in createFiles) {
			if (!grunt.file.isFile(createFiles[key][0])) {
				grunt.file.write(createFiles[key][0], createFiles[key][1]);
				files += '\n' + createFiles[key][0];
			}
		}
		grunt.log.ok('Files created:' + files);
	});
	// TASK SUMMARY
	grunt.registerTask('build', ['webfont', 'jshint', 'uglify', 'sass', 'clean']);
	grunt.registerTask('default', ['build']);
};